Enum Error
pub enum Error {
OutOfBounds,
UnsupportedConversion,
MissingField,
UnknownEnumVariant,
MissingEnumVariantContent,
InvalidValue(Cow<'static, str>),
NamedFieldErrors(ErrorList<NamedFieldError>),
UnnamedFieldErrors(ErrorList<UnnamedFieldError>),
Custom(Cow<'static, str>),
}Expand description
Error.
Variants
OutOfBounds
UnsupportedConversion
MissingField
UnknownEnumVariant
MissingEnumVariantContent
InvalidValue(Cow<'static, str>)
NamedFieldErrors(ErrorList<NamedFieldError>)
UnnamedFieldErrors(ErrorList<UnnamedFieldError>)
Custom(Cow<'static, str>)
Implementations
impl Error
impl Error
pub fn invalid_value<T>(expected: T) -> Errorwhere
T: ToString,
pub fn invalid_value<T>(expected: T) -> Errorwhere
T: ToString,
Create an invalid value error with a given expected type name.
pub const fn invalid_value_static(expected: &'static str) -> Error
pub const fn invalid_value_static(expected: &'static str) -> Error
Create an invalid value error with a given expected type name.
pub fn custom<T>(msg: T) -> Errorwhere
T: ToString,
pub fn custom<T>(msg: T) -> Errorwhere
T: ToString,
Create a custom error with a given error message.
pub const fn custom_static(msg: &'static str) -> Error
pub const fn custom_static(msg: &'static str) -> Error
Create a custom error with a given error message.