Struct NamedFieldError
pub struct NamedFieldError {
pub(crate) field: Cow<'static, str>,
pub(crate) error: Error,
}Expand description
Error associated with a named field.
Fields
field: Cow<'static, str>error: ErrorImplementations
impl NamedFieldError
impl NamedFieldError
pub fn new<T>(field: T, error: Error) -> NamedFieldErrorwhere
T: ToString,
pub fn new<T>(field: T, error: Error) -> NamedFieldErrorwhere
T: ToString,
Create a new error for a given named field.
pub const fn new_static(field: &'static str, error: Error) -> NamedFieldError
pub const fn new_static(field: &'static str, error: Error) -> NamedFieldError
Create a new error for a given named field.
pub fn into_error(self) -> Error
pub fn into_error(self) -> Error
Take the error.